package main

import (
	"database/sql"
	_ "github.com/mattn/go-sqlite3"
	"strings"
)

var accounts = struct {
	CREATE, INSERT, SELECT string
}{
	`CREATE TABLE accounts (
         username VARCHAR(64) NULL,
         email VARCHAR(256) NULL
     )`,
	"INSERT INTO accounts(username, email) values(?,?)",
	"SELECT * FROM accounts",
}

func main() {
	var err error

	// Open existing or new database
	var db *sql.DB
	if db, err = sql.Open("sqlite3", "/tmp/test.db"); err != nil {
		panic(err)
	}
	defer db.Close()

	must(createTable(db))
	must(insertRow(db))
	must(selectRows(db))
}

func must(err error) {
	if err != nil {
		panic(err)
	}
}

func createTable(db *sql.DB) (err error) {
	if _, err = db.Exec(accounts.CREATE); err != nil {
		if !strings.Contains(err.Error(), "already exists") {
			return
		}
	}
	return nil
}

func insertRow(db *sql.DB) (err error) {
	var stmt *sql.Stmt
	if stmt, err = db.Prepare(accounts.INSERT); err != nil {
		return
	}
	defer stmt.Close()
	_, err = stmt.Exec("Ben kenobi", "ben@council.com")
	return
}

func selectRows(db *sql.DB) (err error) {
	var rows *sql.Rows
	if rows, err = db.Query(accounts.SELECT); err != nil {
		return
	}
	defer rows.Close()
	var username, email string
	for rows.Next() {
		if err = rows.Scan(&username, &email); err != nil {
			return
		}
		print(username, ",", email, "\n")
	}
	return
}
